Skip to content
KitploitKITPLOIT
ToolsExploitsBlog
Log in
Einreichen
ToolsExploitsBlog
Einreichen

Hacking-, PenTest- und Cybersicherheits-Tools für Ihr Sicherheitsarsenal!

Kitploit ist ein Verzeichnis von Hacking-, Cybersicherheits- und Pentesting-Tools. Entdecken Sie die neuesten Projekt-Updates, um Schwachstellen zu finden, Systeme zu analysieren, Tests zu automatisieren und Ihre Sicherheit zu stärken.

··Feeds·Kontakt·Datenschutz·© 2026 Kitploit

Tool-Verzeichnis

Kategorien

Alle Kategorien anzeigen
Loading categories
Tools/GitHubGitHub/projectdiscovery/proxify
Paket-Sniffing & AnalyseWeb-Proxys & AbfangenWebsicherheitPenetrationstestsTop in Web-Proxys & Abfangen Nr.3
GitHubprojectdiscovery/proxify

proxify

Ein vielseitiger und portabler Proxy zum Erfassen, Manipulieren und Wiedergeben von HTTP/HTTPS-Traffic unterwegs.

Repository anzeigenWebseite
3.1k26827vor 1 JahrVon Kitploit geprüft

Beliebteste

Alle anzeigen →

Entdecken Sie die meistgenutzten Tools unserer Community.

Alle Tools erkunden

Durchsuchen Sie unsere Tool-Sammlung

Alle Tools anzeigen →
Teilen

proxify

Funktionen • Installation • Nutzung • Proxify ausführen • SSL-Zertifikat installieren • Anwendungen von Proxify • Discord beitreten

Schweizer Taschenmesser-Proxy für schnelle Bereitstellungen. Unterstützt mehrere Vorgänge wie Dump von Anfragen/Antworten, Filterung und Manipulation über DSL-Sprache, vorgelagerte HTTP/Socks5-Proxy. Zusätzlich ermöglicht ein Replay-Dienstprogramm, den abgefangenen Datenverkehr (Anfragen/Antworten mit korrektem Domainnamen) in BurpSuite oder einen anderen Proxy zu importieren, indem einfach der vorgelagerte Proxy auf proxify gesetzt wird.

Funktionen

proxify

  • Abfangen/Manipulieren von HTTP/HTTPS & NICHT-HTTP-Verkehr
  • Unsichtbarer & Thick Clients Traffic-Proxy-Unterstützung
  • TLS MITM-Unterstützung mit Client/Server-Zertifikaten
  • HTTP und SOCKS5-Unterstützung für vorgelagerten Proxy
  • Traffic-Match/Filter und Replace-DSL-Unterstützung
  • Vollständiger Traffic-Dump in Datei (Anfragen/Antworten)
  • Nativer eingebetteter DNS-Server
  • Plugin-Unterstützung zur Dekodierung spezifischer Protokolle (z.B. XMPP/SMTP/FTP/SSH/)
  • Proxify-Traffic-Replay in Burp

Installation

Laden Sie das fertige Binary herunter oder installieren/erstellen Sie es mit GO

go install -v github.com/projectdiscovery/proxify/cmd/proxify@latest

Nutzung

proxify -h

Dies zeigt die Hilfe für das Tool an. Hier sind alle Schalter, die es unterstützt.

Schweizer Taschenmesser-Proxy für schnelle Bereitstellungen. Unterstützt mehrere Vorgänge wie Dump von Anfragen/Antworten, Filterung und Manipulation über DSL-Sprache, vorgelagerte HTTP/Socks5-Proxy

Nutzung:
  ./proxify [flags]

Flags:
AUSGABE:
   -sr, -store-response        Rohe HTTP-Anfrage/-Antwort im Ausgabeverzeichnis speichern (Standard: proxify_logs)
   -o, -output                 Ausgabedatei zum Speichern von Proxify-Logs (Standard: proxify_logs.jsonl)
   -of, -output-format string  Ausgabeformat (jsonl/yaml) (Standard "jsonl")
   -dump-req                   Nur HTTP-Anfragen in Ausgabedatei ausgeben
   -dump-resp                  Nur HTTP-Antworten in Ausgabedatei ausgeben
   -oca, -out-ca string        CA-Datei generieren und unter Dateiname speichern

UPDATE:
   -up, -update                 proxify auf neueste Version aktualisieren
   -duc, -disable-update-check  automatische Prüfung auf Proxify-Updates deaktivieren

FILTER:
   -req-fd, -request-dsl string[]                   Anfrage-Filter-DSL
   -resp-fd, -response-dsl string[]                 Antwort-Filter-DSL
   -req-mrd, -request-match-replace-dsl string[]    Anfrage-Match-Replace-DSL
   -resp-mrd, -response-match-replace-dsl string[]  Antwort-Match-Replace-DSL

NETZWERK:
   -ha, -http-addr string    Lauschende HTTP-IP und Port (ip:port) (Standard "127.0.0.1:8888")
   -sa, -socks-addr string   Lauschende SOCKS-IP und Port (ip:port) (Standard 127.0.0.1:10080)
   -da, -dns-addr string     Lauschende DNS-IP und Port (ip:port)
   -dm, -dns-mapping string  Domain-IP-DNS-Zuordnung (z.B. domain:ip,domain:ip,..)
   -r, -resolver string      Benutzerdefinierte DNS-Resolver verwenden (ip:port)

PROXY:
   -hp, -http-proxy string[]    Vorgelagerte HTTP-Proxies (z.B. http://proxy-ip:proxy-port)
   -sp, -socks5-proxy string[]  Vorgelagerte SOCKS5-Proxies (z.B. socks5://proxy-ip:proxy-port)
   -c int                       Anzahl der Anfragen vor Wechsel zum nächsten vorgelagerten Proxy (Standard 1)

EXPORT:
   -max-size int  Maximale Exportdatengröße (Anfragen/Antworten werden gekürzt) (Standard 9223372036854775807)

KONFIGURATION:
   -config string              Pfad zur Proxify-Konfigurationsdatei
   -ec, -export-config string  Proxify-Exportmodul-Konfigurationsdatei (Standard "$CONFIG/export-config.yaml")
   -config-directory string    Standardkonfigurationspfad überschreiben (Standard "$CONFIG/proxify")
   -cert-cache-size int        Anzahl der zu cachenden Zertifikate (Standard 256)
   -a, -allow string[]         Erlaubte Liste von IP/CIDR, die über den Proxy geleitet werden
   -d, -deny string[]          Verweigerte Liste von IP/CIDR, die über den Proxy geleitet werden
   -pt, -passthrough string[]  Liste der Passthrough-Domains

DEBUG:
   -nc, -no-color      Keine Farbe
   -version            Version
   -silent             Still
   -v, -verbose        Ausführlich
   -vv, -very-verbose  Sehr ausführlich

Proxify ausführen

Startet einen HTTP-Proxy auf Port 8888:

proxify

Startet einen HTTP-Proxy auf benutzerdefiniertem Port 1111:

proxify -http-addr ":1111"

TLS-Passthrough

Das Flag -pt kann verwendet werden, um verschlüsselten Datenverkehr zu überspringen (Passthrough), ohne zu versuchen, die TLS-Verbindung zu beenden.

proxify -pt '(.*\.)?google\.co.in.*'

Proxify mit vorgelagertem Proxy

Startet einen HTTP-Proxy auf Port 8888 und leitet den Verkehr an Burp auf Port 8080 weiter:

proxify -http-proxy http://127.0.0.1:8080

Startet einen HTTP-Proxy auf Port 8888 und leitet den Verkehr an das TOR-Netzwerk weiter:

proxify -socks5-proxy 127.0.0.1:9050

Gesamten HTTP/HTTPS-Verkehr ausgeben

Proxify unterstützt drei Ausgabeformate: JSONL, YAML und Dateien.

JSONL (Standard):

Im JSON-Lines-Format wird jedes Paar aus HTTP-Anfrage/Antwort als JSON-Objekt in einer einzelnen Zeile gespeichert.

Tool herunterladen